@@ -40,17 +40,17 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_security_http_base():
     response = client.get("/users/me", headers={"Authorization": "Other foobar"})
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"scheme": "Other", "credentials": "foobar"}
 
 
 def test_security_http_base_no_credentials():
     response = client.get("/users/me")
-    assert response.status_code == 403
+    assert response.status_code == 403, response.text
     assert response.json() == {"detail": "Not authenticated"}
